# 🌍 MoneroSpace: Decentralized Satellite Network for Monero  

**构建抗审查的去中心化卫星通信网络，让Monero在全球任何角落畅通无阻**  


## 🗺️ 快速导航  
- [项目愿景](#vision) • [核心技术模块](#technical-modules) • [如何贡献](#contribute) • [资金透明度](#finance) • [最新动态](#news)  


## ✨ 项目愿景  
为Monero打造**物理层抗审查基础设施**，通过低轨卫星网络实现：  
- **全球无死角接入**：覆盖偏远地区、海洋及审查区域  
- **去中心化冗余**：卫星节点独立于地面网络，保障交易广播可靠性  
- **社区共建生态**：100%开源硬件/软件，支持第三方部署卫星节点  


## 🛠️ 核心技术模块  
| 模块                | 状态          | 2025年第二季度关键成果                  |  
|---------------------|---------------|-----------------------------------------|  
| 卫星硬件设计        | 筹备中        | 完成3U CubeSat抗辐射组件选型草案         |  
| 节点软件优化        | 筹备中        | 内存占用降低40%（测试阶段）              |  
| 激光通信协议        | 草案阶段      | 完成QPSK调制+LDPC纠错方案设计            |  


## 🤝 如何贡献  
1. **报告问题**：[新建Issue](https://git.openenet.cn/MoneroSpace/Beginner-Repository/issues)（选择标签：`bug`/`enhancement`/`docs`）  
2. **提交代码**：Fork仓库→修改→提交PR（标题格式：`[模块] 功能描述`，例如`hardware: 优化天线展开机构`）  
3. **翻译文档**：联系 `admin@openenet.cn` 获取`Beginner-Repository/docs/`目录翻译任务  
4. **资金审计**：监控`Beginner-Repository/finance/`目录季度报告，参与社区投票审核  
5. **加入团队**：发送简历至 `admin@openenet.cn` 申请技术岗位  


## 💰 资金透明度  
- **预算**：首期30,000 XMR，分4个里程碑拨付（详见[提案文档](#docs)）  
- **手续费机制**：卫星中转交易收取0.03%费用，其中0.015%用于团队日常维护，0.015%注入门罗币社区基金（CCS）  
- **公开库**：所有财务数据采用[CC0 1.0协议](Beginner-Repository/LICENSE)，支持自由审计  


## 🚀 最新动态  
- **2025-04-18**：正式确认卫星交易手续费分配机制，0.015%直接支持Monero社区生态发展  
- **2025-04-20**：团队将参与MoneroTopia直播（北京时间00:00）  


## 📂 目录结构  
```  
MoneroSpace/  
├─ Beginner-Repository/  # 核心内容目录  
 ─ docs/                # 核心文档（提案、技术报告、团队信息）  
 ─ hardware/            # 硬件设计资源（CAD图纸、BOM清单、抗辐射方案）  
 ─ software/            # 卫星节点软件（抗辐射优化代码、激光通信协议）  
 ─ finance/             # 资金透明度数据（预算、支出记录、审计报告）  
 ─ .github/             # 协作工具（Issue模板、CI/CD工作流）  
 ─ LICENSE              # 开源协议汇总（硬件CERN-OHL/软件MIT/数据CC0）  
├─ Beginner-Repository/README.md  # 项目入口文件  
└─ README.md              # 根目录导航文件（当前文件）  
```  


## 🔗 关键链接  
- [CCS提案全文](Beginner-Repository/docs/proposal/OPENENET-MoneroSpace-Satellite-Network-for-monero.md)  
- [团队成员简介](Beginner-Repository/docs/team/members.md)  
- [Gitea项目主页](https://git.openenet.cn/MoneroSpace/Beginner-Repository)（实时追踪开发进度）  

  
*本项目由OPENENET团队发起，采用开放协作模式，欢迎加入我们共建抗审查的Monero未来！*  



### English Version  

# 🌍 MoneroSpace: Decentralized Satellite Network for Monero  

**Building a censorship-resistant decentralized satellite communication network to enable Monero access everywhere**  


## 🗺️ Quick Navigation  
- [Vision](#vision) • [Technical Modules](#technical-modules) • [How to Contribute](#contribute) • [Financial Transparency](#finance) • [News](#news)  


## ✨ Vision  
Create **physical-layer censorship-resistant infrastructure** for Monero through low-earth orbit satellites, achieving:  
- **Global Ubiquitous Access**: Coverage for remote areas, oceans, and censored regions  
- **Decentralized Redundancy**: Satellite nodes operate independently of terrestrial networks to ensure transaction broadcasting reliability  
- **Community-Driven Ecosystem**: 100% open-source hardware/software, enabling third-party satellite node deployment  


## 🛠️ Core Technical Modules  
| Module                | Status        | Key Deliverables (Q2 2025)                |  
|---------------------|---------------|------------------------------------------|  
| Satellite Hardware Design | In Preparation | Completed draft of radiation-hardened component selection for 3U CubeSat |  
| Node Software Optimization | In Preparation | 40% reduction in memory usage (testing phase) |  
| Laser Communication Protocol | Draft Phase   | Completed QPSK modulation + LDPC error correction scheme design |  


## 🤝 How to Contribute  
1. **Report Issues**: [New Issue](https://git.openenet.cn/MoneroSpace/Beginner-Repository/issues) (label with `bug`/`enhancement`/`docs`)  
2. **Submit Code**: Fork the repo → make changes → submit PR (title format: `[Module] Feature Description`, e.g., `hardware: Optimize antenna deployment mechanism`)  
3. **Translate Docs**: Contact `admin@openenet.cn` for translation tasks in the `Beginner-Repository/docs/` directory  
4. **Audit Finances**: Monitor quarterly reports in the `Beginner-Repository/finance/` directory and participate in community votes  
5. **Join the Team**: Send resumes to `admin@openenet.cn` for technical roles  


## 💰 Financial Transparency  
- **Budget**: Initial 30,000 XMR allocated across 4 milestones (see [Proposal Document](#docs))  
- **Transaction Fee Model**: 0.03% fee on satellite-routed transactions, with 0.015% for team maintenance and 0.015% to the Monero Community Chest (CCS)  
- **Open Database**: All financial data under [CC0 1.0 License](Beginner-Repository/LICENSE), allowing free auditing  


## 🚀 Latest News  
- **2025-04-18**: Finalized satellite transaction fee allocation, with 0.015% directly supporting the Monero ecosystem  
- **2025-04-20**: Team will present at MoneroTopia live stream (00:00 UTC+8)


## 📂 Directory Structure  
```  
MoneroSpace/  
├─  # Core content directory  
 ─ docs/                # Core documents (proposals, technical reports, team info)  
 ─ hardware/            # Hardware design resources (CAD, BOM, radiation-hardening plans)  
 ─ software/            # Satellite node software (radiation-optimized code, laser protocols)  
 ─ finance/             # Financial transparency data (budgets, expenditure records, audits)  
 ─ .github/             # Collaboration tools (issue templates, CI/CD workflows)  
 ─ LICENSE              # Open-source license aggregation (hardware CERN-OHL/software MIT/data CC0)  
├─ Beginner-Repository/README.md  # Project homepage  
└─ README.md              # Root directory navigation (current file)  
```  


## 🔗 Key Links  
- [Full CCS Proposal](Beginner-Repository/docs/proposal/OPENENET-MoneroSpace-Satellite-Network-for-monero.md)  
- [Team Members](Beginner-Repository/docs/team/members.md)  
- [Gitea Project Page](https://git.openenet.cn/MoneroSpace/Beginner-Repository) (track development progress in real time)  

  
*Initiated by the OPENENET Team, this project operates under open collaboration. Join us in building a censorship-resistant future for Monero!*  
```  
